@@ -10,4 +10,6 @@ from .nrExtractResources import nrExtractResources
 from .nrPSSIndices import nrPSSIndices
 from .nrTimingEstimate import nrTimingEstimate
 from .nrPBCHDMRSIndices import nrPBCHDMRSIndices
-from .nrSetResources import nrSetResources
\ No newline at end of file
+from .nrSetResources import nrSetResources
+from .nrChannelEstimate import nrChannelEstimate
+from .nrOFDMInfo import nrOFDMInfo
\ No newline at end of file
